@@ -68,6 +68,36 @@ class textProgBar:
             print('~', end='')
         print(' ', flush = True)
 
+def PDF2Uniform(inVec, numBins=10, nUniPoints=None, lowPercentile = 0, highPercentile=100):
+    """
+    This function takes an array of numbers and returns indices of those who
+    form a uniform density over numBins bins, between lowPercentile and highPercentile
+    values in the array. The output vector will have the size nUniPoints.
+    """
+    indPerBin = np.digitize(inVec, np.linspace(np.percentile(inVec, lowPercentile),
+                                          np.percentile(inVec, highPercentile), 
+                                          numBins) )
+    indPerBin[inVec < np.percentile(inVec, lowPercentile)]=0
+    indPerBin[inVec > np.percentile(inVec, highPercentile)]=0
+    binNumber, counts = np.unique(indPerBin, return_counts = True)
+    counts = counts[counts>0]
+
+    if(nUniPoints is None):
+        nUniPoints = int(np.median(counts))
+
+    uniInds = np.zeros(nUniPoints, dtype='uint32')
+    ptCnt = 0
+    while(ptCnt < nUniPoints):
+        for binCnt in binNumber:
+            if(ptCnt >= nUniPoints):
+                break
+            lclInds = np.where(indPerBin==binCnt)[0]
+            if(lclInds.shape[0]>0):
+                uniInds[ptCnt] = np.random.choice(lclInds,1)
+                indPerBin[uniInds[ptCnt]]=0
+                ptCnt += 1            
+    return(uniInds)
+
 def removeIslands(inMask, 
                     minSize = 1):
     """
